CREATE TABLE Gebaeude (
	GCode VARCHAR(20) PRIMARY KEY
);

CREATE TABLE Stockwerk (
	GCode VARCHAR(20) NOT NULL REFERENCES Gebaeude(GCode),
	Nr INTEGER NOT NULL,
	SLevel INTEGER NOT NULL,
	PRIMARY KEY(GCode, Nr)
);

CREATE TABLE Raum (
	GCode VARCHAR(20) NOT NULL,
	Nr INTEGER NOT NULL,
	Id VARCHAR(6) NOT NULL,
	FOREIGN KEY (GCode, Nr) REFERENCES Stockwerk(GCode, Nr),
	PRIMARY KEY (GCode, Nr, Id)
);

CREATE TABLE Gegenstand (
	InvNr INTEGER PRIMARY KEY,
	Bezeichnung VARCHAR(80) NOT NULL,
	Beschreibung VARCHAR(160) NOT NULL,
	Wert INTEGER NOT NULL,
	gcodeLager VARCHAR(20) NOT NULL,
	StockwerkLager INTEGER NOT NULL,
	RaumIdLager VARCHAR(6) NOT NULL,
	FOREIGN KEY (gcodeLager, StockwerkLager, RaumIdLager) REFERENCES Raum(GCode, Nr, Id)
);

CREATE TABLE VersicherterGegenstand (
	InvNr INTEGER PRIMARY KEY REFERENCES Gegenstand(InvNr),
	VSumme NUMERIC(12,2) NOT NULL
);

CREATE TABLE FehlenderGegenstand (
	InvNr INTEGER PRIMARY KEY REFERENCES Gegenstand(InvNr)
);

CREATE TABLE Personal (
	PNr INTEGER PRIMARY KEY,
	VName VARCHAR(20) NOT NULL,
	NName VARCHAR(20) NOT NULL,
	GebDatum DATE NOT NULL
);

CREATE TABLE BioMerkmal (
	PNr INTEGER NOT NULL REFERENCES Personal(PNr),
	Typ VARCHAR(15),
	Daten VARCHAR(15),
	PRIMARY KEY (PNr, Typ)
);

CREATE TABLE Security (
	PNr INTEGER PRIMARY KEY REFERENCES Personal(PNr)
);

CREATE TABLE Schicht (
	Beginn TIMESTAMP NOT NULL,
	Ende TIMESTAMP NOT NULL,
	PRIMARY KEY (Beginn, Ende)
);

CREATE TABLE bewacht (
	GCode VARCHAR(20),
	Stockwerk INTEGER,
	PNr INTEGER, 
	Beginn TIMESTAMP,
	Ende TIMESTAMP,
	FOREIGN KEY(GCode, Stockwerk) REFERENCES Stockwerk(GCode, Nr),
	FOREIGN KEY(PNr) REFERENCES Security(PNr),
	PRIMARY KEY(GCode, Stockwerk, PNr, Beginn, Ende)
);

CREATE TABLE Zugangsversuch (
	Id VARCHAR(8) PRIMARY KEY,
	Datum TIMESTAMP NOT NULL,
	ResultCode VARCHAR(8),
	PNr INTEGER NOT NULL REFERENCES Personal(PNr),
	GCode VARCHAR(20) NOT NULL,
	Stockwerk INTEGER NOT NULL,
	RaumId VARCHAR(6) NOT NULL,
	FOREIGN KEY(GCode, Stockwerk, RaumId) REFERENCES Raum(GCode, Nr, Id)
);

CREATE TABLE PIN (
	ID VARCHAR(8) PRIMARY KEY REFERENCES Zugangsversuch(Id)
);

CREATE TABLE Biometrisch(
	ID VARCHAR(8) PRIMARY KEY REFERENCES Zugangsversuch(Id),
	TrefferGuete NUMERIC(3,2) NOT NULL
);
